<?php

return [
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ',',
    'None' => '無',
    'Edit' => '編輯',
    'Remove' => '移除',
    'Yes' => '是',
    'No' => '否',
    'cancel' => '取消',
    'or' => '或者',
    'Yellow' => '黄色',
    'Blue' => '藍色',
    'Green' => '綠色',
    'Purple' => '紫色',
    'Red' => '红色',
    'Orange' => '橘色',
    'Grey' => '灰色',
    'Brown' => '褐色',
    'Deep Orange' => '橘红色',
    'Dark Grey' => '深灰色',
    'Pink' => '粉红色',
    'Teal' => '青色',
    'Cyan' => '藍綠色',
    'Lime' => '黃綠色',
    'Light Green' => '淺綠色',
    'Amber' => '黄褐色',
    'Save' => '儲存',
    'Login' => '登入',
    'Official website:' => '官方網站：',
    'Unassigned' => '未指派',
    'View this task' => '檢視任務',
    'Remove user' => '移除使用者',
    'Do you really want to remove this user: "%s"?' => '確定要刪除使用者"%s"嗎？',
    'All users' => '所有使用者',
    'Username' => '使用者名稱',
    'Password' => '密碼',
    'Administrator' => '管理員',
    'Sign in' => '登入',
    'Users' => '使用者',
    'Forbidden' => '禁止',
    'Access Forbidden' => '禁止進入',
    'Edit user' => '修改使用者',
    'Logout' => '登出',
    'Bad username or password' => '使用者名稱或密碼錯誤',
    'Edit project' => '修改專案',
    'Name' => '名稱',
    'Projects' => '專案',
    'No project' => '無專案',
    'Project' => '專案',
    'Status' => '狀態',
    'Tasks' => '任務',
    'Board' => '看板',
    'Actions' => '動作',
    'Inactive' => '未啟用',
    'Active' => '啟用',
    'Unable to update this board.' => '無法更新看板。',
    'Disable' => '停用',
    'Enable' => '啟用',
    'New project' => '新建專案',
    'Do you really want to remove this project: "%s"?' => '確定要移除專案"%s"嗎？',
    'Remove project' => '移除專案',
    'Edit the board for "%s"' => '"%s"修改看板',
    'Add a new column' => '新增欄位',
    'Title' => '標題',
    'Assigned to %s' => '指派给 %s',
    'Remove a column' => '刪除一個欄位',
    'Unable to remove this column.' => '無法刪除此欄位。',
    'Do you really want to remove this column: "%s"?' => '確定要移除此欄位"%s"嗎？',
    'Settings' => '設定',
    'Application settings' => '應用程式設定',
    'Language' => '語言',
    'Webhook token:' => 'Webhook token：',
    'API token:' => 'API token：',
    'Database size:' => '資料庫大小：',
    'Download the database' => '下載資料庫',
    'Optimize the database' => '優化資料庫',
    '(VACUUM command)' => '(VACUUM 指令)',
    '(Gzip compressed Sqlite file)' => '(用Gzip壓縮的Sqlite文件)',
    'Close a task' => '關閉任務',
    'Column' => '欄位',
    'Color' => '顏色',
    'Assignee' => '負責人',
    'Create another task' => '新增另一個任務',
    'New task' => '新建任務',
    'Open a task' => '打開任務',
    'Do you really want to open this task: "%s"?' => '確定要打開這個任務嗎？"%s"',
    'Back to the board' => '回到看板',
    'There is nobody assigned' => '無人被指派',
    'Column on the board:' => '看板上的欄位：',
    'Close this task' => '關閉任務',
    'Open this task' => '開啟任務',
    'There is no description.' => '没有描述。',
    'Add a new task' => '新增一個任務',
    'The username is required' => '使用者名稱為必要資料',
    'The maximum length is %d characters' => '最長%d個英文字母',
    'The minimum length is %d characters' => '最短%d個英文字母',
    'The password is required' => '需要密碼',
    'This value must be an integer' => '必須為整数',
    'The username must be unique' => '使用者名稱重複',
    'The user id is required' => '帳號id是必要的',
    'Passwords don\'t match' => '密碼不符',
    'The confirmation is required' => '需要確認',
    'The project is required' => '需要指定專案',
    'The id is required' => '需要指定編號',
    'The project id is required' => '需要指定專案編號',
    'The project name is required' => '需要指定專案名稱',
    'The title is required' => '需要指定標題',
    'Settings saved successfully.' => '設定儲存成功。',
    'Unable to save your settings.' => '無法儲存你的設定。',
    'Database optimization done.' => '資料庫優化完成。',
    'Your project has been created successfully.' => '您的專案已經建立完成。',
    'Unable to create your project.' => '無法建立您的專案。',
    'Project updated successfully.' => '更新專案成功。',
    'Unable to update this project.' => '無法更新專案。',
    'Unable to remove this project.' => '無法移除專案。',
    'Project removed successfully.' => '移除專案成功。',
    'Project activated successfully.' => '專案啟用成功。',
    'Unable to activate this project.' => '無法啟用專案。',
    'Project disabled successfully.' => '停用專案成功。',
    'Unable to disable this project.' => '無法停用專案。',
    'Unable to open this task.' => '無法開啟任務。',
    'Task opened successfully.' => '任務開啟成功。',
    'Unable to close this task.' => '無法關閉任務。',
    'Task closed successfully.' => '關閉任務成功。',
    'Unable to update your task.' => '無法更新您的任務。',
    'Task updated successfully.' => '更新任務成功。',
    'Unable to create your task.' => '無法建立任務。',
    'Task created successfully.' => '任務建立成功。',
    'User created successfully.' => '使用者建立成功。',
    'Unable to create your user.' => '無法建立使用者。',
    'User updated successfully.' => '使用者更新成功。',
    'User removed successfully.' => '使用者移除成功。',
    'Unable to remove this user.' => '無法移除這個使用者。',
    'Board updated successfully.' => '看板更新成功。',
    'Ready' => '預備',
    'Backlog' => '待辦',
    'Work in progress' => '進行中',
    'Done' => '完成',
    'Application version:' => '應用程式版本：',
    'Id' => '編號',
    'Public link' => '公開連結',
    'Timezone' => '時區',
    'Sorry, I didn\'t find this information in my database!' => '抱歉，找不到任何訊息！',
    'Page not found' => '找不到頁面',
    'Complexity' => '複雜度',
    'Task limit' => '任務上限',
    'Task count' => '任務數量',
    'User' => '使用者',
    'Comments' => '評論',
    'Comment is required' => '評論不能空白',
    'Comment added successfully.' => '評論增加完成。',
    'Unable to create your comment.' => '無法建立評論。',
    'Due Date' => '到期日期',
    'Invalid date' => '無效日期',
    'Automatic actions' => '自動化動作',
    'Your automatic action has been created successfully.' => '您的自動化動作已建立',
    'Unable to create your automatic action.' => '無法建立自動化動作。',
    'Remove an action' => '移除一個自動化動作。',
    'Unable to remove this action.' => '無法移除自動化動作',
    'Action removed successfully.' => '移除自動化動作成功。',
    'Automatic actions for the project "%s"' => '專案"%s"的自動化動作',
    'Add an action' => '增加一個動作',
    'Event name' => '事件名稱',
    'Action' => '動作',
    'Event' => '事件',
    'When the selected event occurs execute the corresponding action.' => '當所選事件發生時執行動作。',
    'Next step' => '下一步',
    'Define action parameters' => '定義動作参数',
    'Do you really want to remove this action: "%s"?' => '確定要移除此動作"%s"嗎？',
    'Remove an automatic action' => '移除自動化動作',
    'Assign the task to a specific user' => '將任務指派给使用者',
    'Assign the task to the person who does the action' => '將任務指派给產生動作的使用者',
    'Duplicate the task to another project' => '複製此任務到另一專案',
    'Move a task to another column' => '移動任務到另一欄位',
    'Task modification' => '任務修改',
    'Task creation' => '任務建立',
    'Closing a task' => '正在關閉任務',
    'Assign a color to a specific user' => '指派顏色給特定使用者',
    'Position' => '位置',
    'Duplicate to project' => '複製到另一專案',
    'Duplicate' => '複製',
    'Link' => '連接',
    'Comment updated successfully.' => '評論更新成功。',
    'Unable to update your comment.' => '無法更新您的評論。',
    'Remove a comment' => '移除一則評論',
    'Comment removed successfully.' => '評論移除成功。',
    'Unable to remove this comment.' => '無法移除評論。',
    'Do you really want to remove this comment?' => '確定要移除此評論嗎？',
    'Current password for the user "%s"' => '使用者"%s"的目前密碼',
    'The current password is required' => '需要輸入目前的密碼',
    'Wrong password' => '密碼錯誤',
    'Unknown' => '未知',
    'Last logins' => '上次登入',
    'Login date' => '登入日期',
    'Authentication method' => '認證方式',
    'IP address' => 'IP位址',
    'User agent' => '瀏覽器標示',
    'Persistent connections' => '登入會話',
    'No session.' => '無會話',
    'Expiration date' => '過期日期',
    'Remember Me' => '記住我',
    'Creation date' => '建立日期',
    'Everybody' => '所有人',
    'Open' => '打開',
    'Closed' => '關閉',
    'Search' => '搜尋',
    'Nothing found.' => '找不到任何資料。',
    'Due date' => '到期日期',
    'Description' => '描述',
    '%d comments' => '%d個評論',
    '%d comment' => '%d個評論',
    'Email address invalid' => '無效的電子信箱',
    'Your external account is not linked anymore to your profile.' => '你的外部帳號關聯已解除',
    'Unable to unlink your external account.' => '無法關聯到你的外部帳號',
    'External authentication failed' => '外部認證失败',
    'Your external account is linked to your profile successfully.' => '你已成功關聯到你的外部帳號',
    'Email' => '電子信箱',
    'Task removed successfully.' => '刪除任務完成',
    'Unable to remove this task.' => '無法刪除任務。',
    'Remove a task' => '刪除一個任務',
    'Do you really want to remove this task: "%s"?' => '確定要刪除此任務"%s"嗎？',
    'Assign automatically a color based on a category' => '自動指派顏色到一個分類',
    'Assign automatically a category based on a color' => '自動指派分類到一個顏色',
    'Task creation or modification' => '任務建立或修改',
    'Category' => '分類',
    'Category:' => '分類：',
    'Categories' => '分類',
    'Your category has been created successfully.' => '建立分類成功。',
    'This category has been updated successfully.' => '更新分類成功。',
    'Unable to update this category.' => '無法更新分類。',
    'Remove a category' => '移除一個分類',
    'Category removed successfully.' => '分類移除成功。',
    'Unable to remove this category.' => '無法移除分類。',
    'Category modification for the project "%s"' => '為專案"%s"修改分類',
    'Category Name' => '分類名稱',
    'Add a new category' => '加入新分類',
    'Do you really want to remove this category: "%s"?' => '確定要移除此分類"%s"ㄇㄚ？',
    'All categories' => '所有分類',
    'No category' => '無分類',
    'The name is required' => '必需要有名字',
    'Remove a file' => '移除一個文件',
    'Unable to remove this file.' => '無法移除文件。',
    'File removed successfully.' => '文件移除成功。',
    'Attach a document' => '附加文件',
    'Do you really want to remove this file: "%s"?' => '確定要移除文件"%s"嗎？',
    'Attachments' => '附件',
    'Edit the task' => '修改任務',
    'Add a comment' => '新增評論',
    'Edit a comment' => '編輯評論',
    'Summary' => '摘要',
    'Time tracking' => '時間紀錄',
    'Estimate:' => '預估：',
    'Spent:' => '花費：',
    'Do you really want to remove this sub-task?' => '確認要刪除此子任務？',
    'Remaining:' => '剩餘：',
    'hours' => '小時',
    'estimated' => '預估',
    'Sub-Tasks' => '子任務',
    'Add a sub-task' => '增加子任務',
    'Original estimate' => '初步預估',
    'Create another sub-task' => '建立另一個子任務',
    'Time spent' => '時間花費',
    'Edit a sub-task' => '編輯子任務',
    'Remove a sub-task' => '刪除子任務',
    'The time must be a numeric value' => '時間必需是數字',
    'Todo' => '待完成',
    'In progress' => '正在進行',
    'Sub-task removed successfully.' => '删除子任務成功',
    'Unable to remove this sub-task.' => '無法删除此任務',
    'Sub-task updated successfully.' => '建立子任務成功',
    'Unable to update your sub-task.' => '無法更新子任務',
    'Unable to create your sub-task.' => '無法建立子任務',
    'Maximum size: ' => '大小上限：',
    'Display another project' => '顯示其它專案',
    'Created by %s' => '建立者：%s',
    'Tasks Export' => '任務匯出',
    'Start Date' => '開始時間',
    'Execute' => '執行',
    'Task Id' => '任務編號',
    'Creator' => '建立者',
    'Modification date' => '修改日期',
    'Completion date' => '完成日期',
    'Clone' => '複製',
    'Project cloned successfully.' => '複製專案成功。',
    'Unable to clone this project.' => '無法複製專案',
    'Enable email notifications' => '啟用郵件通知',
    'Task position:' => '任務位置：',
    'The task #%d has been opened.' => '任務#%d已經被打開.',
    'The task #%d has been closed.' => '任務#%d已經被關閉.',
    'Sub-task updated' => '子任務已更新',
    'Title:' => '標題：',
    'Status:' => '狀態：',
    'Assignee:' => '負責人：',
    'Time tracking:' => '時間紀錄',
    'New sub-task' => '新建子任務',
    'New attachment added "%s"' => '加入新附件"%s"',
    'New comment posted by %s' => '%s 的新評論',
    'New comment' => '新增評論',
    'Comment updated' => '更新了評論',
    'New subtask' => '新建子任務',
    'I only want to receive notifications for these projects:' => '我謹需要收到下面專案的通知：',
    'view the task on Kanboard' => '在看板中查看此任務',
    'Public access' => '公開瀏覽',
    'Disable public access' => '停止公開瀏覽',
    'Enable public access' => '開啟公開瀏覽',
    'Public access disabled' => '已經禁止公開瀏覽',
    'Move the task to another project' => '移動任務到其它專案',
    'Move to project' => '移動到其它專案',
    'Do you really want to duplicate this task?' => '確認要複製此任務嗎？',
    'Duplicate a task' => '複製任務',
    'External accounts' => '外部帳號',
    'Account type' => '帳號類型',
    'Local' => '本地',
    'Remote' => '遠端',
    'Enabled' => '啟用',
    'Disabled' => '停用',
    'Login:' => '使用者名稱：',
    'Full Name:' => '姓名：',
    'Email:' => 'Email：',
    'Notifications:' => '通知：',
    'Notifications' => '通知',
    'Account type:' => '帳號類型：',
    'Edit profile' => '編輯屬性',
    'Change password' => '修改密碼',
    'Password modification' => '修改密碼',
    'External authentications' => '外部認證',
    'Never connected.' => '從未連接。',
    'No external authentication enabled.' => '未啟用外部認證。',
    'Password modified successfully.' => '修改密碼成功。',
    'Unable to change the password.' => '無法修改密碼。',
    'Change category' => '變更分類',
    '%s updated the task %s' => '%s 更新了任務 %s',
    '%s opened the task %s' => '%s 開啟了任務 %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s 將任務 %s 移動到"%s"的第#%d個位置',
    '%s moved the task %s to the column "%s"' => '%s 移動任務 %s 到欄位 "%s"',
    '%s created the task %s' => '%s 建立了任務 %s',
    '%s closed the task %s' => '%s 關閉了任務 %s',
    '%s created a subtask for the task %s' => '%s 建立了 %s的子任務',
    '%s updated a subtask for the task %s' => '%s 更新了 %s的子任務',
    'Assigned to %s with an estimate of %s/%sh' => '分派给 %s，預估需要 %s/%s 小時',
    'Not assigned, estimate of %sh' => '未分派，預估需要 %s 小時',
    '%s updated a comment on the task %s' => '%s 更新了任務 %s的評論',
    '%s commented the task %s' => '%s 評論了任務 %s',
    '%s\'s activity' => '%s的動態',
    'RSS feed' => 'RSS 連結',
    '%s updated a comment on the task #%d' => '%s 更新了任務 #%d 的評論',
    '%s commented on the task #%d' => '%s 評論了任務 #%d',
    '%s updated a subtask for the task #%d' => '%s 更新了任務 #%d 的子任務',
    '%s created a subtask for the task #%d' => '%s 建立了任務 #%d 的子任務',
    '%s updated the task #%d' => '%s 更新了任務 #%d',
    '%s created the task #%d' => '%s 建立了任務 #%d',
    '%s closed the task #%d' => '%s 關閉了任務 #%d',
    '%s opened the task #%d' => '%s 開啟了任務 #%d',
    'Activity' => '動態',
    'Default values are "%s"' => '預設值為 "%s"',
    'Default columns for new projects (Comma-separated)' => '新建專案的預設欄位(用逗號分開)',
    'Task assignee change' => '任務分配變更',
    '%s changed the assignee of the task #%d to %s' => '%s 將任務 #%d 分配给了 %s',
    '%s changed the assignee of the task %s to %s' => '%s 將任務 %s 分配给 %s',
    'New password for the user "%s"' => '使用者"%s"的新密碼',
    'Choose an event' => '選擇一個事件',
    'Create a task from an external provider' => '從外部建立任務',
    'Change the assignee based on an external username' => '根據外部使用者名稱修改任務分配',
    'Change the category based on an external label' => '根據外部標籤修改分類',
    'Reference' => '參考',
    'Label' => '標籤',
    'Database' => '資料庫',
    'About' => '關於',
    'Database driver:' => '資料庫驅動：',
    'Board settings' => '看板設定',
    'Webhook settings' => 'Webhook 設定',
    'Reset token' => '重設 token',
    'API endpoint:' => 'API endpoint：',
    'Refresh interval for personal board' => '私人看板的更新時間',
    'Refresh interval for public board' => '公共看板的更新時間',
    'Task highlight period' => '任務高亮時間',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => '多久内的任務視為剛剛修改(單位：秒,設為0提用，預設是2天',
    'Frequency in second (60 seconds by default)' => '頻率,單位為秒(預設是60秒)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => '頻率,單位為秒(設為0停用此功能，預設是10秒)',
    'Application URL' => '應用程式URL',
    'Token regenerated.' => 'Token已重新產生',
    'Date format' => '日期格式',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO 格式總是允許的，例如："%s" 和 "%s"',
    'New personal project' => '新建私人專案',
    'This project is personal' => '此專案為私人專案',
    'Add' => '增加',
    'Start date' => '開始日期',
    'Time estimated' => '預計時間',
    'There is nothing assigned to you.' => '目前無任務指派给你。',
    'My tasks' => '我的任務',
    'Activity stream' => '動態記錄',
    'Dashboard' => '儀表板',
    'Confirmation' => '確認',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => '從外部建立一個評論',
    'Project management' => '專案管理',
    'Columns' => '欄位',
    'Task' => '任務',
    'Percentage' => '百分比',
    'Number of tasks' => '任務數',
    'Task distribution' => '任務分佈',
    'Analytics' => '分析',
    'Subtask' => '子任務',
    'User repartition' => '使用者分析',
    'Clone this project' => '複製此專案',
    'Column removed successfully.' => '删除欄位成功。',
    'Not enough data to show the graph.' => '資料不足，無法繪圖。',
    'Previous' => '上一頁',
    'The id must be an integer' => '編號必須為整數',
    'The project id must be an integer' => '專案編號必須為整數',
    'The status must be an integer' => '狀態必須為整數',
    'The subtask id is required' => '必須提供子任務編號',
    'The subtask id must be an integer' => '子任務編號必須為整數',
    'The task id is required' => '需要任務編號',
    'The task id must be an integer' => '任務編號必須為整数',
    'The user id must be an integer' => '使用者編號必須為整數',
    'This value is required' => '這個數值是必要的',
    'This value must be numeric' => '這個值必須為數字',
    'Unable to create this task.' => '無法建立此任務。',
    'Cumulative flow diagram' => '累積流程圖',
    'Daily project summary' => '每日專案匯總',
    'Daily project summary export' => '匯出每日專案匯總',
    'Exports' => '匯出',
    'This export contains the number of tasks per column grouped per day.' => '此匯出包含每列的任務數，按天分组',
    'Active swimlanes' => '活動里程碑',
    'Add a new swimlane' => '增加新里程碑',
    'Default swimlane' => '預設里程碑',
    'Do you really want to remove this swimlane: "%s"?' => '確定要删除里程碑："%s"?',
    'Inactive swimlanes' => '非活動里程碑',
    'Remove a swimlane' => '删除里程碑',
    'Swimlane modification for the project "%s"' => '專案"%s"的里程碑變更',
    'Swimlane removed successfully.' => '删除里程碑成功',
    'Swimlanes' => '里程碑',
    'Swimlane updated successfully.' => '更新里程碑成功。',
    'Unable to remove this swimlane.' => '無法删除此里程碑',
    'Unable to update this swimlane.' => '無法更新此里程碑',
    'Your swimlane has been created successfully.' => '你的里程碑已成功建立。',
    'Example: "Bug, Feature Request, Improvement"' => '範例：“缺陷，功能需求，提升',
    'Default categories for new projects (Comma-separated)' => '新項目的預設分類(用逗號分隔)',
    'Integrations' => '整合',
    'Integration with third-party services' => '與第三方服務整合',
    'Subtask Id' => '子任務編號',
    'Subtasks' => '子任務',
    'Subtasks Export' => '子任務匯出',
    'Task Title' => '任務標題',
    'Untitled' => '無標題',
    'Application default' => '程序預設',
    'Language:' => '語言：',
    'Timezone:' => '時區：',
    'All columns' => '全部欄位',
    'Next' => '下一頁',
    '#%d' => '#%d',
    'All swimlanes' => '全部里程碑',
    'All colors' => '全部顏色',
    'Moved to column %s' => '移動到欄位 %s',
    'User dashboard' => '使用者儀俵板',
    'Allow only one subtask in progress at the same time for a user' => '每使用者同時只能有一個活動子任務',
    'Edit column "%s"' => '編輯欄位"%s"',
    'Select the new status of the subtask: "%s"' => '選擇子任務的新狀態："%s"',
    'Subtask timesheet' => '子任務時間表',
    'There is nothing to show.' => '目前無内容可顯示。',
    'Time Tracking' => '時間追踪',
    'You already have one subtask in progress' => '你已經有一個進行中的子任務',
    'Which parts of the project do you want to duplicate?' => '要複製專案的哪些内容？',
    'Disallow login form' => '禁止登入',
    'Start' => '開始',
    'End' => '結束',
    'Task age in days' => '任務存在天數',
    'Days in this column' => '在此欄位的天數',
    '%dd' => '%d天',
    'Add a new link' => '增加一個新連結',
    'Do you really want to remove this link: "%s"?' => '確認要删除此連結嗎:"%s"?',
    'Do you really want to remove this link with task #%d?' => '確認要删除與任務 #%d 的連結嗎？',
    'Field required' => '必要的欄位',
    'Link added successfully.' => '增加連結成功。',
    'Link updated successfully.' => '更新連結成功。',
    'Link removed successfully.' => '删除連結成功。',
    'Link labels' => '連結標籤',
    'Link modification' => '連結修改',
    'Opposite label' => '反向標籤',
    'Remove a link' => '删除連結',
    'The labels must be different' => '標籤不能相同',
    'There is no link.' => '目前没有連結',
    'This label must be unique' => '標籤必需是唯一的',
    'Unable to create your link.' => '無法建立連結。',
    'Unable to update your link.' => '無法更新連結。',
    'Unable to remove this link.' => '無法删除連結。',
    'relates to' => '關聯到',
    'blocks' => '阻塞',
    'is blocked by' => '阻塞於',
    'duplicates' => '重複',
    'is duplicated by' => '重複於',
    'is a child of' => '子任務自',
    'is a parent of' => '父任務於',
    'targets milestone' => '里程碑目標',
    'is a milestone of' => '屬於里程碑',
    'fixes' => '修復',
    'is fixed by' => '修復於',
    'This task' => '此任務',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => '展開任務',
    'Collapse tasks' => '收合任務',
    'Expand/collapse tasks' => '展開/收合任務',
    'Close dialog box' => '關閉對話框',
    'Submit a form' => '提交表單',
    'Board view' => '面板視圖',
    'Keyboard shortcuts' => '鍵盤快速鍵',
    'Open board switcher' => '打開面板切換器',
    'Application' => '應用程序',
    'Compact view' => '緊湊視圖',
    'Horizontal scrolling' => '水平捲動',
    'Compact/wide view' => '緊湊/寬視圖',
    'Currency' => '貨幣',
    'Personal project' => '私人項目',
    'AUD - Australian Dollar' => '澳幣',
    'CAD - Canadian Dollar' => '加元',
    'CHF - Swiss Francs' => '瑞士法郎',
    'Custom Stylesheet' => '自定義樣式表',
    'EUR - Euro' => '歐元',
    'GBP - British Pound' => '英鎊',
    'INR - Indian Rupee' => '印度盧比',
    'JPY - Japanese Yen' => '日元',
    'NZD - New Zealand Dollar' => '紐西蘭元',
    'PEN - Peruvian Sol' => 'PEN - 秘鲁索尔',
    'RSD - Serbian dinar' => '第納爾',
    'CNY - Chinese Yuan' => '人民幣',
    'USD - US Dollar' => '美元',
    'VES - Venezuelan Bolívar' => 'VES - 委內瑞拉玻利瓦爾',
    'Destination column' => '目標欄位',
    'Move the task to another column when assigned to a user' => '指定負責人時移動到其它欄位',
    'Move the task to another column when assignee is cleared' => '移除負責人時移動到其它欄位',
    'Source column' => '原欄位',
    'Transitions' => '變更',
    'Executer' => '執行者',
    'Time spent in the column' => '欄位中的時間消耗',
    'Task transitions' => '任務變更',
    'Task transitions export' => '匯出任務變更',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => '此報告紀錄任務的變更，包含日期、使用者和時間消耗。',
    'Currency rates' => '匯率',
    'Rate' => '匯率',
    'Change reference currency' => '修改参考貨幣',
    'Reference currency' => '参考貨幣',
    'The currency rate has been added successfully.' => '增加匯率成功。',
    'Unable to add this currency rate.' => '無法增加此匯率',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s删除了任務%s的負責人',
    'Information' => '訊息',
    'Check two factor authentication code' => '檢查雙重認證碼',
    'The two factor authentication code is not valid.' => '雙重認證碼不正確。',
    'The two factor authentication code is valid.' => '雙重認證碼正確。',
    'Code' => '認證碼',
    'Two factor authentication' => '雙重認證',
    'This QR code contains the key URI: ' => '此二維條碼包含密碼 URI:',
    'Check my code' => '檢查我的認證碼',
    'Secret key: ' => '密碼：',
    'Test your device' => '測試你的設備',
    'Assign a color when the task is moved to a specific column' => '任務移動到指定欄位時設定顏色',
    '%s via Kanboard' => '%s 通過KanBoard',
    'Burndown chart' => '燃盡圖',
    'This chart show the task complexity over the time (Work Remaining).' => '圖表顯示任務複雜度基於時間(剩餘時間)',
    'Screenshot taken %s' => '已截圖 %s',
    'Add a screenshot' => '增加截圖',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => '獲取截圖並按CTRL+V或者⌘+V黏貼到這裡',
    'Screenshot uploaded successfully.' => '截圖上傳成功',
    'SEK - Swedish Krona' => '瑞郎',
    'Identifier' => '標示符',
    'Disable two factor authentication' => '停用雙重認證',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => '你真的要停用 "%s" 的雙重認證嗎？',
    'Edit link' => '編輯連結',
    'Start to type task title...' => '輸入任務標題...',
    'A task cannot be linked to itself' => '任務不能連結到本身',
    'The exact same link already exists' => '相同的連結已存在',
    'Recurrent task is scheduled to be generated' => '循環性任務將按計畫生成',
    'Score' => '積分',
    'The identifier must be unique' => '標示符必須唯一',
    'This linked task id doesn\'t exists' => '連結的任務不存在',
    'This value must be alphanumeric' => '此值必須是字母或者數字',
    'Edit recurrence' => '編輯循環週期',
    'Generate recurrent task' => '生成循環任務',
    'Trigger to generate recurrent task' => '生成循環任務的觸發器',
    'Factor to calculate new due date' => '逾期因素',
    'Timeframe to calculate new due date' => '計算逾期時間表',
    'Base date to calculate new due date' => '計算逾期基準日期',
    'Action date' => '操作日期',
    'Base date to calculate new due date: ' => '基準日期',
    'This task has created this child task: ' => '此任務建立了子任務：',
    'Day(s)' => '天',
    'Existing due date' => '已逾期',
    'Factor to calculate new due date: ' => '超期因素',
    'Month(s)' => '月',
    'This task has been created by: ' => '此任務建立者：',
    'Recurrent task has been generated:' => '循環任務已建立：',
    'Timeframe to calculate new due date: ' => '計算逾期時間表',
    'Trigger to generate recurrent task: ' => '建立循環任務的觸發器',
    'When task is closed' => '當任務關閉時',
    'When task is moved from first column' => '當任務從第一列任務欄移走時',
    'When task is moved to last column' => '當任務移動到最後一列任務欄時',
    'Year(s)' => '年',
    'Project settings' => '專案設定',
    'Automatically update the start date' => '自動更新開始日期',
    'iCal feed' => '日曆訂閱',
    'Preferences' => '偏好',
    'Security' => '安全',
    'Two factor authentication disabled' => '雙重認證已停用',
    'Two factor authentication enabled' => '雙重認證已啟用',
    'Unable to update this user.' => '無法更新此使用者',
    'There is no user management for personal projects.' => '私人專案下無使用者可管理',
    'User that will receive the email' => '使用者將收到郵件',
    'Email subject' => '郵件主旨',
    'Date' => '日期',
    'Add a comment log when moving the task between columns' => '當任務移動到任務欄時增加評論日誌',
    'Move the task to another column when the category is changed' => '當任務分類改變時移動到任務欄',
    'Send a task by email to someone' => '發送任務郵件給使用者',
    'Reopen a task' => '重新開始任務',
    'Notification' => '通知',
    '%s moved the task #%d to the first swimlane' => '%s將任務#%d移動到首個里程碑',
    'Swimlane' => '里程碑',
    '%s moved the task %s to the first swimlane' => '%s將任務%s移動到首個里程碑',
    '%s moved the task %s to the swimlane "%s"' => '%s將任務%s移動到里程碑"%s"下',
    'This report contains all subtasks information for the given date range.' => '該報告包含了指定日期範圍内的所有子任務訊息。',
    'This report contains all tasks information for the given date range.' => '該報告包含了指定日期範圍内的所有任務訊息。',
    'Project activities for %s' => '%s的項目活動紀錄',
    'view the board on Kanboard' => '在看板上查看面板',
    'The task has been moved to the first swimlane' => '該任務已被移動到首個里程碑',
    'The task has been moved to another swimlane:' => '乾任務已被移動到别的里程碑：',
    'New title: %s' => '新標題：%s',
    'The task is not assigned anymore' => '該任務没有指派人',
    'New assignee: %s' => '新指派人：%s',
    'There is no category now' => '目前没有分類',
    'New category: %s' => '新分類：%s',
    'New color: %s' => '新顏色：%s',
    'New complexity: %d' => '新的複雜度：%d',
    'The due date has been removed' => '到期時間已被移除',
    'There is no description anymore' => '目前没有描述',
    'Recurrence settings has been modified' => '循環週期已被更改',
    'Time spent changed: %sh' => '時間花費已變更：%sh',
    'Time estimated changed: %sh' => '時間預估已變更：%sh',
    'The field "%s" has been updated' => '"%s"欄位已更新',
    'The description has been modified:' => '描述已更改',
    'Do you really want to close the task "%s" as well as all subtasks?' => '你是否要關閉此父任務包括所有子任務"%s"',
    'I want to receive notifications for:' => '我想接收以下相關通知：',
    'All tasks' => '所有任務',
    'Only for tasks assigned to me' => '所有指派给我的任務',
    'Only for tasks created by me' => '所有我建立的任務',
    'Only for tasks created by me and tasks assigned to me' => '所有我建立的並且指派给我的任務',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => '所有欄位下的',
    'You need at least 2 days of data to show the chart.' => '柱狀圖至少需要2天的資料。',
    '<15m' => '小於15分鐘',
    '<30m' => '小於30分鐘',
    'Stop timer' => '停止計時器',
    'Start timer' => '啟動計時器',
    'My activity stream' => '我的動態',
    'Search tasks' => '搜尋任務',
    'Reset filters' => '重置過濾器',
    'My tasks due tomorrow' => '我明天到期的任務',
    'Tasks due today' => '今天到期的任務',
    'Tasks due tomorrow' => '明天到期的任務',
    'Tasks due yesterday' => '昨天到期的任務',
    'Closed tasks' => '已關閉的任務',
    'Open tasks' => '打開的任務',
    'Not assigned' => '未指派',
    'View advanced search syntax' => '查看高级搜尋語法',
    'Overview' => '總覽',
    'Board/Calendar/List view' => '看板/日程/列表視圖',
    'Switch to the board view' => '切换到看板視圖',
    'Switch to the list view' => '切换到列表視圖',
    'Go to the search/filter box' => '前往搜尋/過濾箱',
    'There is no activity yet.' => '目前無任何活動.',
    'No tasks found.' => '找不到任何任務.',
    'Keyboard shortcut: "%s"' => '快速鍵: "%s"',
    'List' => '列表',
    'Filter' => '過濾器',
    'Advanced search' => '高级搜尋',
    'Example of query: ' => '查詢範例: ',
    'Search by project: ' => '依專案: ',
    'Search by column: ' => '依任務欄: ',
    'Search by assignee: ' => '依被指派人: ',
    'Search by color: ' => '依颜色: ',
    'Search by category: ' => '依分類：',
    'Search by description: ' => '依描述：',
    'Search by due date: ' => '依逾期時間：',
    'Average time spent in each column' => '每個任務欄的平均花費時間',
    'Average time spent' => '平均花費時間',
    'This chart shows the average time spent in each column for the last %d tasks.' => '目前柱狀圖表示最新%d條任務在每個任務欄下的平均花費時間',
    'Average Lead and Cycle time' => '平均工作時間和平均週期時間',
    'Average lead time: ' => '平均工作時間',
    'Average cycle time: ' => '平均周期時間: ',
    'Cycle Time' => '週期時間',
    'Lead Time' => '工作時間',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => '目前柱狀圖表示最新%d條任務的平均工作時間和週期時間',
    'Average time into each column' => '每個任務欄的平均時間',
    'Lead and cycle time' => '工作時間和週期時間',
    'Lead time: ' => '工作時間: ',
    'Cycle time: ' => '週期時間: ',
    'Time spent in each column' => '每個任務欄的花費時間',
    'The lead time is the duration between the task creation and the completion.' => '工作是任務建立和完成之間的持續時間。',
    'The cycle time is the duration between the start date and the completion.' => '周期時間是開始日期和完成時間之間的持續時間。',
    'If the task is not closed the current time is used instead of the completion date.' => '如果目前任務未關閉時用目前時間代替完成時間',
    'Set the start date automatically' => '設定自動開始日期',
    'Edit Authentication' => '編輯認證訊息',
    'Remote user' => '遠端使用者',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => '遠端使用者不會在看板資料庫保存密碼，例如：LDAP,GOOGLE,GitHub。',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => '如果選擇“禁止登入來自”，登入表單内的驗證訊息將被忽略。',
    'Default task color' => '預設任務顏色',
    'This feature does not work with all browsers.' => '本功能只在部分瀏覽器運作。',
    'There is no destination project available.' => '目前没有目標專案可用',
    'Trigger automatically subtask time tracking' => '自動追蹤子任務時間',
    'Include closed tasks in the cumulative flow diagram' => '在累計流程圖中包含已關閉任務',
    'Current swimlane: %s' => '目前里程碑：%s',
    'Current column: %s' => '目前任務欄：%s',
    'Current category: %s' => '目前分類：%s',
    'no category' => '無分類',
    'Current assignee: %s' => '目前被指派人: %s',
    'not assigned' => '未指派',
    'Author:' => '作者',
    'contributors' => '貢獻者',
    'License:' => '授權許可:',
    'License' => '授權許可',
    'Enter the text below' => '輸入下方的文字',
    'Start date:' => '開始日期',
    'Due date:' => '到期日期',
    'People who are project managers' => '專案管理員',
    'People who are project members' => '專案成員',
    'NOK - Norwegian Krone' => '克朗',
    'Show this column' => '顯示任務欄',
    'Hide this column' => '隱藏任務欄',
    'End date' => '结束日期',
    'Users overview' => '使用者總覽',
    'Members' => '成員',
    'Shared project' => '公開專案',
    'Project managers' => '專案管理員',
    'Projects list' => '專案列表',
    'End date:' => '结束日期',
    'Change task color when using a specific task link' => '當任務關聯到指定任務時改變顏色',
    'Task link creation or modification' => '任務連接建立或更新時間',
    'Milestone' => '里程碑',
    'Reset the search/filter box' => '重設搜尋/過濾框',
    'Documentation' => '文件',
    'Author' => '作者',
    'Version' => '版本',
    'Plugins' => '插件',
    'There is no plugin loaded.' => '目前没有插件載入',
    'My notifications' => '我的通知',
    'Custom filters' => '自定義過濾器',
    'Your custom filter has been created successfully.' => '建立過濾器成功',
    'Unable to create your custom filter.' => '無法建立過濾器',
    'Custom filter removed successfully.' => '删除過濾器成功',
    'Unable to remove this custom filter.' => '無法删除這個過濾器',
    'Edit custom filter' => '編輯過濾器',
    'Your custom filter has been updated successfully.' => '你的過濾器更新成功',
    'Unable to update custom filter.' => '無法更新過濾器',
    'Web' => 'web',
    'New attachment on task #%d: %s' => '任務#%d下的新附件：%s',
    'New comment on task #%d' => '任務#%d下的新評論',
    'Comment updated on task #%d' => '任務#%d的評論已更新',
    'New subtask on task #%d' => '任務#%d下新的子任務',
    'Subtask updated on task #%d' => '任務#%d下的子任務已更新',
    'New task #%d: %s' => '新任務#%d：%s',
    'Task updated #%d' => '任務#%d已更新',
    'Task #%d closed' => '任務#%d已關閉',
    'Task #%d opened' => '任務#%d已打開',
    'Column changed for task #%d' => '任務#%d的任務欄已改變',
    'New position for task #%d' => '任務#%d的新狀態',
    'Swimlane changed for task #%d' => '任務#%d的里程碑已改變',
    'Assignee changed on task #%d' => '任務#%d的指派人已改變',
    '%d overdue tasks' => '%d條逾期任務',
    'No notification.' => '没有新通知',
    'Mark all as read' => '標記所有為已讀',
    'Mark as read' => '標記為已讀',
    'Total number of tasks in this column across all swimlanes' => '此任務欄下的任務數（跨里程碑）',
    'Collapse swimlane' => '收起里程碑',
    'Expand swimlane' => '展開里程碑',
    'Add a new filter' => '增加新過濾器',
    'Share with all project members' => '對專案所有成員共享',
    'Shared' => '共享',
    'Owner' => '所有人',
    'Unread notifications' => '未讀通知',
    'Notification methods:' => '通知提醒方式：',
    'Unable to read your file' => '無法讀取文件',
    '%d task(s) have been imported successfully.' => '成功匯入%d條任務。',
    'Nothing has been imported!' => '没有資料被匯入！',
    'Import users from CSV file' => '從CSV文件匯入帳號',
    '%d user(s) have been imported successfully.' => '成功匯入%d個帳號。',
    'Comma' => '逗號',
    'Semi-colon' => '分號',
    'Tab' => '製表符',
    'Vertical bar' => '豎線',
    'Double Quote' => '雙引號',
    'Single Quote' => '單引號',
    '%s attached a file to the task #%d' => '%s增加文件到任務#%d',
    'There is no column or swimlane activated in your project!' => '目前專案没有活動任務欄或里程碑',
    'Append filter (instead of replacement)' => '追加過濾',
    'Append/Replace' => '追加/替换',
    'Append' => '追加',
    'Replace' => '替换',
    'Import' => '匯入',
    'Change sorting' => '改變排序',
    'Tasks Importation' => '任務重要性',
    'Delimiter' => '分隔符',
    'Enclosure' => '附件',
    'CSV File' => 'CSV文件',
    'Instructions' => '操作指南',
    'Your file must use the predefined CSV format' => '文件必須為CSV格式',
    'Your file must be encoded in UTF-8' => '文件編碼必須為UTF-8',
    'The first row must be the header' => '第一行必須為表頭',
    'Duplicates are not verified for you' => '無法驗證重複訊息',
    'The due date must use the ISO format: YYYY-MM-DD' => '到期日期必須為ISO格式：YYYY-MM-DD',
    'Download CSV template' => '下載CSV範本',
    'No external integration registered.' => '没有外部註冊訊息',
    'Duplicates are not imported' => '重複資料未匯入',
    'Usernames must be lowercase and unique' => '帳號名稱必需小寫且不重複',
    'Passwords will be encrypted if present' => '密碼將被加密',
    '%s attached a new file to the task %s' => '"%s"增加了附件到任務"%s"',
    'Link type' => '連結類型',
    'Assign automatically a category based on a link' => '根據連結自動分類',
    'BAM - Konvertible Mark' => '波斯尼亞馬克',
    'Assignee Username' => '指派使用者',
    'Assignee Name' => '指派名稱',
    'Groups' => '使用者群組',
    'Members of %s' => '“%s”组成员',
    'New group' => '新增使用者群組',
    'Group created successfully.' => '使用者群组建立成功',
    'Unable to create your group.' => '無法建立使用者群組',
    'Edit group' => '編輯使用者群組',
    'Group updated successfully.' => '使用者群組更新成功',
    'Unable to update your group.' => '無法更新你的使用者群組',
    'Add group member to "%s"' => '增加到群組"%s"',
    'Group member added successfully.' => '增加群組成員成功',
    'Unable to add group member.' => '無法增加群組成员',
    'Remove user from group "%s"' => '從"%s"群組中移除成員',
    'User removed successfully from this group.' => '使用者已從該群組中删除',
    'Unable to remove this user from the group.' => '無法從群組中中删除使用者',
    'Remove group' => '删除群組',
    'Group removed successfully.' => '群組已删除',
    'Unable to remove this group.' => '無法删除群組',
    'Project Permissions' => '專案權限',
    'Manager' => '管理員',
    'Project Manager' => '專案管理員',
    'Project Member' => '專案成員',
    'Project Viewer' => '專案觀察員',
    'Your account is locked for %d minutes' => '你的帳號被鎖定%d分鐘',
    'Invalid captcha' => '驗證碼無效',
    'The name must be unique' => '帳號名稱不能重複',
    'View all groups' => '查看所有群組',
    'There is no user available.' => '目前無有效使用者',
    'Do you really want to remove the user "%s" from the group "%s"?' => '你確定把使用者"%s"從"%s"中移除？',
    'There is no group.' => '目前没有群組',
    'Add group member' => '增加群組成員',
    'Do you really want to remove this group: "%s"?' => '確認要移除群組："%s"？',
    'There is no user in this group.' => '目前群組下没有成員',
    'Permissions' => '權限',
    'Allowed Users' => '被允許的使用者',
    'No specific user has been allowed.' => '没有被允許的使用者。',
    'Role' => '角色',
    'Enter user name...' => '輸入使用者...',
    'Allowed Groups' => '被允許的群組',
    'No group has been allowed.' => '没有被允許的群組。',
    'Group' => '群組',
    'Group Name' => '群組名稱',
    'Enter group name...' => '輸入群組名稱...',
    'Role:' => '角色:',
    'Project members' => '專案成員',
    '%s mentioned you in the task #%d' => '%s在任務#%d裡提到您',
    '%s mentioned you in a comment on the task #%d' => '%s在任務#%d的評論中提到您',
    'You were mentioned in the task #%d' => '您在任務#%d中被提到',
    'You were mentioned in a comment on the task #%d' => '您在任務#%d評論中被提到',
    'Estimated hours: ' => '預估小時數',
    'Actual hours: ' => '實際小時數',
    'Hours Spent' => '花費小時數',
    'Hours Estimated' => '預估小時數',
    'Estimated Time' => '預估時間',
    'Actual Time' => '實際時間',
    'Estimated vs actual time' => '預估時間 VS 實際時間',
    'RUB - Russian Ruble' => '盧布',
    'Assign the task to the person who does the action when the column is changed' => '當任務所属任務欄改變時分配到指定使用者',
    'Close a task in a specific column' => '關閉指定任務欄下的任務',
    'Time-based One-time Password Algorithm' => '基於時間的一次性密碼算法',
    'Two-Factor Provider: ' => '雙重認證提供者',
    'Disable two-factor authentication' => '停用雙重認證',
    'Enable two-factor authentication' => '啟用雙重認證',
    'There is no integration registered at the moment.' => '目前没有註冊關聯',
    'Password Reset for Kanboard' => '重設kanboard密碼',
    'Forgot password?' => '忘記密碼？',
    'Enable "Forget Password"' => '啟用找回密碼',
    'Password Reset' => '密碼重置',
    'New password' => '新密碼',
    'Change Password' => '更改密碼',
    'To reset your password click on this link:' => '點擊此連結重置您的密碼',
    'Last Password Reset' => '上次密碼重置',
    'The password has never been reinitialized.' => '密碼從未被重新初始化',
    'Creation' => '建立時間',
    'Expiration' => '過期時間',
    'Password reset history' => '密碼重置紀錄',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '任務欄 "%s" 和 里程碑 "%s" 下的所有任務已關閉',
    'Do you really want to close all tasks of this column?' => '你確定要關閉此任務欄下的所有任務？',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '任務欄 "%s" 和 里程碑 "%s" 下 %d 任務將被關閉。',
    'Close all tasks in this column and this swimlane' => '關閉此任務欄下的所有任務',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '没有插件註冊到專案通知API，你仍然可以在你個人設定裡啟用單獨的通知',
    'My dashboard' => '我的儀表板',
    'My profile' => '我的個人訊息',
    'Project owner: ' => '專案負責人',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => '專案標示符是可選的,且只能是數字或字母组成，例如：MYPROJECT。',
    'Project owner' => '專案負責人',
    'Personal projects do not have users and groups management.' => '私人專案下沒有成員或群組可管理',
    'There is no project member.' => '目前没有專案成員',
    'Priority' => '優先權',
    'Task priority' => '任務優先權',
    'General' => '常用',
    'Dates' => '時間',
    'Default priority' => '預設優先權',
    'Lowest priority' => '最低優先權',
    'Highest priority' => '最高優先權',
    'Close a task when there is no activity' => '當没有活動紀錄時關閉任務',
    'Duration in days' => '持續天數',
    'Send email when there is no activity on a task' => '當任務没有活動紀錄時發送郵件',
    'Unable to fetch link information.' => '無法獲取連結資訊',
    'Daily background job for tasks' => '每日後台任務',
    'Auto' => '自動',
    'Related' => '相關的',
    'Attachment' => '附件',
    'Web Link' => '網頁連結',
    'External links' => '外部連結',
    'Add external link' => '增加外部連結',
    'Type' => '類型',
    'Dependency' => '依赖',
    'Add internal link' => '增加内部連結',
    'Add a new external link' => '增加新的外部連結',
    'Edit external link' => '編輯外部連結',
    'External link' => '外部連結',
    'Copy and paste your link here...' => '複製並貼上連結到目前位置...',
    'URL' => 'URL',
    'Internal links' => '内部連結',
    'Assign to me' => '指派给我',
    'Me' => '我',
    'Do not duplicate anything' => '不再重複',
    'Projects management' => '專案管理',
    'Users management' => '用户管理',
    'Groups management' => '群組管理',
    'Create from another project' => '從另一個專案建立',
    'open' => '打開',
    'closed' => '已關閉',
    'Priority:' => '優先權：',
    'Reference:' => '引用：',
    'Complexity:' => '複雜度：',
    'Swimlane:' => '里程碑：',
    'Column:' => '欄位：',
    'Position:' => '位置：',
    'Creator:' => '建立者：',
    'Time estimated:' => '時間已過去：',
    '%s hours' => '%s 小時',
    'Time spent:' => '時間消耗：',
    'Created:' => '已建立：',
    'Modified:' => '已修改：',
    'Completed:' => '已完成：',
    'Started:' => '已開始：',
    'Moved:' => '已移走：',
    'Task #%d' => '任務#%d',
    'Time format' => '時間格式',
    'Start date: ' => '開始時間：',
    'End date: ' => '结束時間：',
    'New due date: ' => '新到期時間：',
    'Start date changed: ' => '開始時間已改變：',
    'Disable personal projects' => '停用私人專案',
    'Do you really want to remove this custom filter: "%s"?' => '你確定要移除這個自定義過濾器："%s"？',
    'Remove a custom filter' => '移除自定義過濾器',
    'User activated successfully.' => '帳號已啟用。',
    'Unable to enable this user.' => '無法啟用帳號。',
    'User disabled successfully.' => '帳號已禁用。',
    'Unable to disable this user.' => '無法禁用帳號。',
    'All files have been uploaded successfully.' => '所有文件已成功上傳。',
    'The maximum allowed file size is %sB.' => '最大上傳尺寸 %sB',
    'Drag and drop your files here' => '拖放文件到這裡',
    'choose files' => '選擇文件',
    'View profile' => '查看個人訊息',
    'Two Factor' => '雙重認證',
    'Disable user' => '禁用帳號',
    'Do you really want to disable this user: "%s"?' => '你確定要禁用帳號："%s"？',
    'Enable user' => '啟用帳號',
    'Do you really want to enable this user: "%s"?' => '你確定要啟用帳號："%s"？',
    'Download' => '下載',
    'Uploaded: %s' => '上傳：%s',
    'Size: %s' => '大小：%s',
    'Uploaded by %s' => '由%s上傳',
    'Filename' => '檔案名稱',
    'Size' => '大小',
    'Column created successfully.' => '新增任務欄成功。',
    'Another column with the same name exists in the project' => '目前專案中相同名稱欄位已存在',
    'Default filters' => '預設過濾器',
    'Your board doesn\'t have any columns!' => '你的看板没有任何欄位',
    'Change column position' => '更改任務欄位置',
    'Switch to the project overview' => '切换到项目視圖',
    'User filters' => '使用者過濾器',
    'Category filters' => '分類過濾器',
    'Upload a file' => '上傳文件',
    'View file' => '查看文件',
    'Last activity' => '最後活動',
    'Change subtask position' => '更改子任務位置',
    'This value must be greater than %d' => '目前輸入值必須大於%d',
    'Another swimlane with the same name exists in the project' => '目前專案中相同名稱里程碑已存在',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => '例如： https://example.kanboard.org/（通常用於產生永久網址）',
    'Actions duplicated successfully.' => '動作複製成功。',
    'Unable to duplicate actions.' => '無法複製動作。',
    'Add a new action' => '增加新動作',
    'Import from another project' => '從另一個專案中匯入',
    'There is no action at the moment.' => '目前没有動作。',
    'Import actions from another project' => '從另一個專案中匯入動作',
    'There is no available project.' => '目前没有可用專案',
    'Local File' => '本機文件',
    'Configuration' => '配置選項',
    'PHP version:' => 'PHP 版本：',
    'PHP SAPI:' => 'PHP SAPI：',
    'OS version:' => '作業系统：',
    'Database version:' => '資料庫版本：',
    'Browser:' => '瀏覽器：',
    'Task view' => '任務瀏覽',
    'Edit task' => '編輯任務',
    'Edit description' => '編輯描述',
    'New internal link' => '新增内部連結',
    'Display list of keyboard shortcuts' => '顯示快速鍵列表',
    'Avatar' => '頭像',
    'Upload my avatar image' => '上傳我的頭像',
    'Remove my image' => '删除我的頭像',
    'The OAuth2 state parameter is invalid' => 'OAuth2狀態參數無效',
    'User not found.' => '找不到帳號',
    'Search in activity stream' => '在活動紀錄裡搜尋',
    'My activities' => '我的活動紀錄',
    'Activity until yesterday' => '今天以前的活動紀錄',
    'Activity until today' => '今天為止的活動紀錄',
    'Search by creator: ' => '以建立者搜尋',
    'Search by creation date: ' => '以建立日期搜尋',
    'Search by task status: ' => '以任務狀態搜尋',
    'Search by task title: ' => '以任務標題搜尋',
    'Activity stream search' => '活動紀錄搜尋',
    'Projects where "%s" is manager' => '"%s"　管理的專案',
    'Projects where "%s" is member' => '"%s"　參與的專案',
    'Open tasks assigned to "%s"' => '指派给"%s"的未結束任務',
    'Closed tasks assigned to "%s"' => '指派给"%s"的已结束任務',
    'Assign automatically a color based on a priority' => '基於優先權自動標記顏色',
    'Overdue tasks for the project(s) "%s"' => '"%s"專案下的逾期任務',
    'Upload files' => '上傳文件',
    'Installed Plugins' => '已安装插件',
    'Plugin Directory' => '插件目錄',
    'Plugin installed successfully.' => '插件安装成功。',
    'Plugin updated successfully.' => '插件更新成功。',
    'Plugin removed successfully.' => '插件卸載成功。',
    'Subtask converted to task successfully.' => '子任務成功轉換成普通任務。',
    'Unable to convert the subtask.' => '無法轉換子任務。',
    'Unable to extract plugin archive.' => '無法解壓縮插件包。',
    'Plugin not found.' => '插件未找到。',
    'You don\'t have the permission to remove this plugin.' => '你没有權限移除此插件。',
    'Unable to download plugin archive.' => '無法下載插件包。',
    'Unable to write temporary file for plugin.' => '無法為插件寫入臨時文件。',
    'Unable to open plugin archive.' => '無法打開插件包。',
    'There is no file in the plugin archive.' => '目前插件包内無文件。',
    'Create tasks in bulk' => '批次建立任務',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => '你的Kanboard没有啟用插件安装。',
    'There is no plugin available.' => '目前無可用插件。',
    'Install' => '安装',
    'Update' => '更新',
    'Up to date' => '已更新',
    'Not available' => '不可用',
    'Remove plugin' => '移除插件',
    'Do you really want to remove this plugin: "%s"?' => '你真的要移除插件："%s"？',
    'Uninstall' => '移除',
    'Listing' => '列表',
    'Metadata' => 'Metadata',
    'Manage projects' => '管理專案',
    'Convert to task' => '轉為普通任務',
    'Convert sub-task to task' => '轉換子任務為普通任務',
    'Do you really want to convert this sub-task to a task?' => '你真的要將此子任務轉換為普通任務？',
    'My task title' => '我的任務標題',
    'Enter one task by line.' => '寫入一行任務。',
    'Number of failed login:' => '登入失敗次數：',
    'Account locked until:' => '帳號被鎖定至：',
    'Email settings' => '郵件設定',
    'Email sender address' => '郵件發送地址',
    'Email transport' => '郵件轉發',
    'Webhook token' => 'Webhook Token',
    'Project tags management' => '專案標籤管理',
    'Tag created successfully.' => '成功建立標籤。',
    'Unable to create this tag.' => '無法建立此標籤。',
    'Tag updated successfully.' => '標籤更新成功。',
    'Unable to update this tag.' => '無法更新此標籤。',
    'Tag removed successfully.' => '標籤删除成功。',
    'Unable to remove this tag.' => '無法删除此標籤',
    'Global tags management' => '全域標籤管理',
    'Tags' => '標籤',
    'Tags management' => '標籤管理',
    'Add new tag' => '增加新標籤',
    'Edit a tag' => '編輯標籤',
    'Project tags' => '專案標籤',
    'There is no specific tag for this project at the moment.' => '目前專案没有指定任何標籤。',
    'Tag' => '標籤',
    'Remove a tag' => '移除標籤',
    'Do you really want to remove this tag: "%s"?' => '你真的要删除此標籤："%s"？',
    'Global tags' => '全域標籤',
    'There is no global tag at the moment.' => '目前没有全域標籤。',
    'This field cannot be empty' => '此欄不能為空',
    'Close a task when there is no activity in a specific column' => '當指定欄位没有更新時關閉任務',
    '%s removed a subtask for the task #%d' => '"%s"從任務#%d删除了子任務',
    '%s removed a comment on the task #%d' => '"%s"從任務#%d删除了評論',
    'Comment removed on task #%d' => '任務#%d上的評論已删除',
    'Subtask removed on task #%d' => '任務#%d上的子任務已删除',
    'Hide tasks in this column in the dashboard' => '在儀表板隱藏此欄下的任務',
    '%s removed a comment on the task %s' => '"%s"從任務%s 删除了評論',
    '%s removed a subtask for the task %s' => '"%s"從任務%s 删除了子任務',
    'Comment removed' => '評論已删除',
    'Subtask removed' => '子任務已删除',
    '%s set a new internal link for the task #%d' => '%s為任務#%d 設置了新内部連結',
    '%s removed an internal link for the task #%d' => '%s 從任務 #%d 删除内部連結',
    'A new internal link for the task #%d has been defined' => '#%d新内部連結已定義',
    'Internal link removed for the task #%d' => '#%d内部連結已删除',
    '%s set a new internal link for the task %s' => '%s為任務%s設置了新連結',
    '%s removed an internal link for the task %s' => '%s删除了任務%s内部連結',
    'Automatically set the due date on task creation' => '建立任務時自動設定過期時間',
    'Move the task to another column when closed' => '當任務關閉時移動到另一欄',
    'Move the task to another column when not moved during a given period' => '當任務在指定時間内未移動時，移動到另一欄',
    'Dashboard for %s' => '%s的儀表板',
    'Tasks overview for %s' => '%s的任務預覽',
    'Subtasks overview for %s' => '%s的子任務預覽',
    'Projects overview for %s' => '%s的專案預覽',
    'Activity stream for %s' => '%s的活動紀錄',
    'Assign a color when the task is moved to a specific swimlane' => '當任務移動到指定里程碑時標記顏色',
    'Assign a priority when the task is moved to a specific swimlane' => '當任務移動到指定里程碑時標記優先權',
    'User unlocked successfully.' => '帳號解鎖成功。',
    'Unable to unlock the user.' => '無法解鎖帳號。',
    'Move a task to another swimlane' => '移動任務到里程碑',
    'Creator Name' => '建立者名稱',
    'Time spent and estimated' => '時間花費預估',
    'Move position' => '移動位置',
    'Move task to another position on the board' => '移動任務到另一個位置',
    'Insert before this task' => '在此任務之前插入',
    'Insert after this task' => '在此任務之後插入',
    'Unlock this user' => '解鎖帳號',
    'Custom Project Roles' => '自定義專案角色',
    'Add a new custom role' => '增加新角色',
    'Restrictions for the role "%s"' => '"%s"角色限制',
    'Add a new project restriction' => '增加新的專案限制',
    'Add a new drag and drop restriction' => '增加新的拖放限制',
    'Add a new column restriction' => '增加新的欄位限制',
    'Edit this role' => '編輯角色',
    'Remove this role' => '删除角色',
    'There is no restriction for this role.' => '目前角色無限制。',
    'Only moving task between those columns is permitted' => '只能在以下欄位間移動任務',
    'Close a task in a specific column when not moved during a given period' => '當指定欄位下的任務在指定時間内未移動時關閉任務',
    'Edit columns' => '編輯欄位',
    'The column restriction has been created successfully.' => '建立欄位限制成功。',
    'Unable to create this column restriction.' => '無法建立欄位限制。',
    'Column restriction removed successfully.' => '删除欄位限制成功。',
    'Unable to remove this restriction.' => '無法删除限制。',
    'Your custom project role has been created successfully.' => '自定義項目角色建立成功。',
    'Unable to create custom project role.' => '無法删除自定義專案角色。',
    'Your custom project role has been updated successfully.' => '自定義项目角色更新成功。',
    'Unable to update custom project role.' => '無法更新自定義專案角色。',
    'Custom project role removed successfully.' => '删除自定義專案角色成功。',
    'Unable to remove this project role.' => '無法删除專案角色。',
    'The project restriction has been created successfully.' => '建立專案限制成功。',
    'Unable to create this project restriction.' => '無法建立專案限制。',
    'Project restriction removed successfully.' => '删除專案限制成功。',
    'You cannot create tasks in this column.' => '你不能在此欄位下建立任務。',
    'Task creation is permitted for this column' => '目前欄位下允許建立任務。',
    'Closing or opening a task is permitted for this column' => '目前欄位下允許開關任務。',
    'Task creation is blocked for this column' => '目前欄位下禁止建立任務。',
    'Closing or opening a task is blocked for this column' => '禁止在此欄位下開關任務',
    'Task creation is not permitted' => '不能建立任務',
    'Closing or opening a task is not permitted' => '禁止開關任務',
    'New drag and drop restriction for the role "%s"' => '為角色"%s"新建拖動限制',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => '此角色下的用户只能在原欄位和目標欄位間移動任務。',
    'Remove a column restriction' => '移除欄位限制',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => '你真的要删除欄位限制："%s"到"%s"？',
    'New column restriction for the role "%s"' => '為角色"%s"增加欄位限制？',
    'Rule' => '規則',
    'Do you really want to remove this column restriction?' => '你真的要移除欄位限制？',
    'Custom roles' => '自定義角色',
    'New custom project role' => '新建專案角色',
    'Edit custom project role' => '編輯專案角色',
    'Remove a custom role' => '删除自定義角色',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '你真的要删除這個自定義角色："%s"？目前角色下的成員將轉成普通專案成員。',
    'There is no custom role for this project.' => '目前專案没有自定義角色',
    'New project restriction for the role "%s"' => '给角色"%s"新建專案限制',
    'Restriction' => '限制',
    'Remove a project restriction' => '移除專案限制',
    'Do you really want to remove this project restriction: "%s"?' => '你真的要删除專案限制："%s"？',
    'Duplicate to multiple projects' => '複製到多個專案',
    'This field is required' => '此欄位必填',
    'Moving a task is not permitted' => '禁止移動任務',
    'This value must be in the range %d to %d' => '輸入值必須在%d到%d之間',
    'You are not allowed to move this task.' => '你不能移動此任務',
    'API User Access' => 'API access',
    'Preview' => '預覽',
    'Write' => '寫入',
    'Write your text in Markdown' => '使用markdown格式',
    'No personal API access token registered.' => '没有API access token 註冊。',
    'Your personal API access token is "%s"' => '你的API access token 是 “%s”',
    'Remove your token' => '移除token',
    'Generate a new token' => '產生新的token',
    'Showing %d-%d of %d' => '本頁顯示 %d-%d 筆，共有: %d 筆',
    'Outgoing Emails' => '目標郵件',
    'Add or change currency rate' => '增加/更改匯率',
    'Reference currency: %s' => '参考匯率：%s',
    'Add custom filters' => '添加自定義過濾',
    'Export' => '匯出',
    'Add link label' => '增加連結標籤',
    'Incompatible Plugins' => '不相容插件',
    'Compatibility' => '相容性',
    'Permissions and ownership' => '權限和擁有者',
    'Priorities' => '屬性',
    'Close this window' => '關閉視窗',
    'Unable to upload this file.' => '無法上傳此文件。',
    'Import tasks' => '匯入任務',
    'Choose a project' => '選擇專案',
    'Profile' => '個人資料',
    'Application role' => '應用角色',
    '%d invitations were sent.' => '%d個邀請已發送。',
    '%d invitation was sent.' => '%d個邀請已發送。',
    'Unable to create this user.' => '無法建立用戶。',
    'Kanboard Invitation' => '看板邀請',
    'Visible on dashboard' => '儀表板可見',
    'Created at:' => '建立於：',
    'Updated at:' => '更新於：',
    'There is no custom filter.' => '目前没有自定義過濾。',
    'New User' => '新增使用者',
    'Authentication' => '認證',
    'If checked, this user will use a third-party system for authentication.' => '選取時使用者將使用第三方系统認證。',
    'The password is necessary only for local users.' => '只有本機使用者才需要設定密碼。',
    'You have been invited to register on Kanboard.' => '你被邀請註冊看板。',
    'Click here to join your team' => '點擊這裡加入你的團隊',
    'Invite people' => '邀請新使用者',
    'Emails' => '郵件',
    'Enter one email address by line.' => '輸入郵件位址，每行一個。',
    'Add these people to this project' => '增加使用者到專案',
    'Add this person to this project' => '增加使用者到專案',
    'Sign-up' => '註冊',
    'Credentials' => '認證訊息',
    'New user' => '新使用者',
    'This username is already taken' => '帳號名稱已被使用',
    'Your profile must have a valid email address.' => '個人資料必須有一個有效email位址。',
    'TRL - Turkish Lira' => '土耳其里拉',
    'The project email is optional and could be used by several plugins.' => '專案郵件位址可選，使用於插件。',
    'The project email must be unique across all projects' => '專案郵件地址必須全域唯一',
    'The email configuration has been disabled by the administrator.' => '郵件設定被管理員禁用。',
    'Close this project' => '關閉專案',
    'Open this project' => '打開專案',
    'Close a project' => '關閉專案',
    'Do you really want to close this project: "%s"?' => '你真的要關閉專案："%s"？',
    'Reopen a project' => '重開專案',
    'Do you really want to reopen this project: "%s"?' => '你真的要重開專案："%s"？',
    'This project is open' => '專案已打開',
    'This project is closed' => '專案已關閉',
    'Unable to upload files, check the permissions of your data folder.' => '無法上傳文件，請檢查你的data目錄權限。',
    'Another category with the same name exists in this project' => '此项目中存在另一个同名类别',
    'Comment sent by email successfully.' => '評論已成功通過電子郵件發送。',
    'Sent by email to "%s" (%s)' => '通過電子郵件發送給 "%s" (%s)',
    'Unable to read uploaded file.' => '無法讀取上傳的檔案。',
    'Database uploaded successfully.' => '資料庫成功上傳。',
    'Task sent by email successfully.' => '任務已成功通過電子郵件發送。',
    'There is no category in this project.' => '目前專案没有分類。',
    'Send by email' => '發送郵件',
    'Create and send a comment by email' => '通過電子郵件建立和發送評論',
    'Subject' => '主旨',
    'Upload the database' => '上傳資料庫',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => '您可以上傳之前下載的 Sqlite 資料庫 (Gzip 格式)。',
    'Database file' => '資料庫檔案',
    'Upload' => '上傳',
    'Your project must have at least one active swimlane.' => '您的專案必須至少有一個作用中的泳道。',
    'Project: %s' => '專案：%s',
    'Automatic action not found: "%s"' => '找不到自動動作: "%s"',
    '%d projects' => '%d 專案',
    '%d project' => '%d 專案',
    'There is no project.' => '目前没有專案。',
    'Sort' => '排序',
    'Project ID' => '專案編號',
    'Project name' => '專案名稱',
    'Public' => '公開',
    'Personal' => '私人',
    '%d tasks' => '%d 任務',
    '%d task' => '%d 任務',
    'Task ID' => '任務編號',
    'Assign automatically a color when due date is expired' => '當截止日期過期時自動分配顏色',
    'Total score in this column across all swimlanes' => '此列所有泳道的總分數',
    'HRK - Kuna' => 'HRK - 克羅埃西亞庫納',
    'ARS - Argentine Peso' => 'ARS - 阿根廷比索',
    'COP - Colombian Peso' => 'COP - 哥倫比亞比索',
    '%d groups' => '%d 群組',
    '%d group' => '%d 群組',
    'Group ID' => '群組編號',
    'External ID' => '外部 ID',
    '%d users' => '%d 使用者',
    '%d user' => '%d 使用者',
    'Hide subtasks' => '顯示子任務',
    'Show subtasks' => '隱藏子任務',
    'Authentication Parameters' => '認證參數',
    'API Access' => 'API 存取',
    'No users found.' => '找不到使用者。',
    'User ID' => '使用者編號',
    'Notifications are activated' => '通知已啟用',
    'Notifications are disabled' => '通知已停用',
    'User disabled' => '帳號已禁用',
    '%d notifications' => '%d 通知',
    '%d notification' => '%d 通知',
    'There is no external integration installed.' => '未安裝外部整合。',
    'You are not allowed to update tasks assigned to someone else.' => '您不允許更新分配給其他人的任務。',
    'You are not allowed to change the assignee.' => '您不允許更改被分配人。',
    'Task suppression is not permitted' => '不允許壓制任務',
    'Changing assignee is not permitted' => '不允許更改被分配人',
    'Update only assigned tasks is permitted' => '只允許更新分配的任務',
    'Only for tasks assigned to the current user' => '僅限於分配給當前使用者的任務',
    'My projects' => '我的專案',
    'You are not a member of any project.' => '你不是任何專案的成員。',
    'My subtasks' => '我的子任務',
    '%d subtasks' => '%d 子任務',
    '%d subtask' => '%d 子任務',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => '僅允許分配給當前使用者的任務在這些列之間移動',
    '[DUPLICATE]' => '[重複]',
    'DKK - Danish Krona' => 'DKK - 丹麥克朗',
    'Remove user from group' => '從群組中移除使用者',
    'Assign the task to its creator' => '將任務分配给建立者',
    'This task was sent by email to "%s" with subject "%s".' => '此任務已通過電子郵件發送給 "%s"，主旨為 "%s"。',
    'Predefined Email Subjects' => '預定義的郵件主旨',
    'Write one subject by line.' => '每行寫一個主旨。',
    'Create another link' => '建立另一個連結',
    'BRL - Brazilian Real' => 'BRL - 巴西雷亞爾',
    'Add a new Kanboard task' => '新增 Kanboard 任務',
    'Subtask not started' => '子任務未開始',
    'Subtask currently in progress' => '子任務目前正在進行中',
    'Subtask completed' => '子任務已完成',
    'Subtask added successfully.' => '子任務已成功新增。',
    '%d subtasks added successfully.' => '已成功新增 %d 個子任務。',
    'Enter one subtask by line.' => '每行輸入一個子任務。',
    'Predefined Contents' => '預定義內容',
    'Predefined contents' => '預定義內容',
    'Predefined Task Description' => '預定義任務描述',
    'Do you really want to remove this template? "%s"' => '您確定要移除此範本嗎？ "%s"',
    'Add predefined task description' => '新增預定義任務描述',
    'Predefined Task Descriptions' => '預定義任務描述',
    'Template created successfully.' => '範本已成功建立。',
    'Unable to create this template.' => '無法建立此範本。',
    'Template updated successfully.' => '範本已成功更新。',
    'Unable to update this template.' => '無法更新此範本。',
    'Template removed successfully.' => '範本已成功移除。',
    'Unable to remove this template.' => '無法移除此範本。',
    'Template for the task description' => '任務描述範本',
    'The start date is greater than the end date' => '開始日期晚於結束日期',
    'Tags must be separated by a comma' => '標籤必須用逗號分隔',
    'Only the task title is required' => '僅任務標題為必填',
    'Creator Username' => '建立者使用者名稱',
    'Color Name' => '顏色名稱',
    'Column Name' => '欄位名稱',
    'Swimlane Name' => '泳道名稱',
    'Time Estimated' => '預計時間',
    'Time Spent' => '花費時間',
    'External Link' => '外部連結',
    'This feature enables the iCal feed, RSS feed and the public board view.' => '此功能啟用 iCal feed、RSS feed 和公開看板檢視。',
    'Stop the timer of all subtasks when moving a task to another column' => '將任務移動到另一列時停止所有子任務的計時器',
    'Subtask Title' => '子任務標題',
    'Add a subtask and activate the timer when moving a task to another column' => '新增子任務並在將任務移動到另一列時啟用計時器',
    'days' => '天',
    'minutes' => '分鐘',
    'seconds' => '秒',
    'Assign automatically a color when preset start date is reached' => '達到預設開始日期時自動分配顏色',
    'Move the task to another column once a predefined start date is reached' => '達到預定義開始日期後將任務移動到另一列',
    'This task is now linked to the task %s with the relation "%s"' => '此任務現已使用關係 "%s" 連結到任務 %s',
    'The link with the relation "%s" to the task %s has been removed' => '與任務 %s 的關係 "%s" 的連結已移除',
    'Custom Filter:' => '自訂篩選器：',
    'Unable to find this group.' => '無法找到此群組。',
    '%s moved the task #%d to the column "%s"' => '%s 將任務 #%d 移動到欄 "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s 將任務 #%d 移動到欄 "%s" 的位置 %d',
    '%s moved the task #%d to the swimlane "%s"' => '%s 將任務 #%d 移動到泳道 "%s"',
    '%sh spent' => '已花費 %sh',
    '%sh estimated' => '預計 %sh',
    'Select All' => '全選',
    'Unselect All' => '取消全選',
    'Apply action' => '應用動作',
    'Move selected tasks to another column or swimlane' => '將選定的任務移動到另一列或泳道',
    'Edit tasks in bulk' => '批量編輯任務',
    'Choose the properties that you would like to change for the selected tasks.' => '選擇要變更所選任務的屬性。',
    'Configure this project' => '設定此專案',
    'Start now' => '立即開始',
    '%s removed a file from the task #%d' => '%s 從任務 #%d 移除了檔案',
    'Attachment removed from task #%d: %s' => '從任務 #%d 移除的附件：%s',
    'No color' => '無顏色',
    'Attachment removed "%s"' => '附件 "%s" 已移除',
    '%s removed a file from the task %s' => '%s 從任務 %s 移除了檔案',
    'Move the task to another swimlane when assigned to a user' => '將任務分配給使用者時移動到另一個泳道',
    'Destination swimlane' => '目標泳道',
    'Assign a category when the task is moved to a specific swimlane' => '當任務移動到特定泳道時分配類別',
    'Move the task to another swimlane when the category is changed' => '當類別變更時移動任務到另一個泳道',
    'Reorder this column by priority (ASC)' => '按優先級重排此列 (升序)',
    'Reorder this column by priority (DESC)' => '按優先級重排此列 (降序)',
    'Reorder this column by assignee and priority (ASC)' => '按被分配者和優先級重排此列 (升序)',
    'Reorder this column by assignee and priority (DESC)' => '按被分配者和優先級重排此列 (降序)',
    'Reorder this column by assignee (A-Z)' => '按被分配者 (A-Z) 重排此列',
    'Reorder this column by assignee (Z-A)' => '按被分配者 (Z-A) 重排此列',
    'Reorder this column by due date (ASC)' => '按截止日期重排此列 (升序)',
    'Reorder this column by due date (DESC)' => '按截止日期重排此列 (降序)',
    'Reorder this column by id (ASC)' => '按 ID 重排此列 (升序)',
    'Reorder this column by id (DESC)' => '按 ID 重排此列 (降序)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s 將任務 #%d "%s" 移動到專案 "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => '任務 #%d "%s" 已移至專案 "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => '當截止日期少於特定天數時將任務移動到另一列',
    'Automatically update the start date when the task is moved away from a specific column' => '當任務從特定欄位移開時，自動更新開始日期',
    'HTTP Client:' => 'HTTP 客戶端:',
    'Assigned' => '已分配',
    'Task limits apply to each swimlane individually' => '任務限制個別應用於每個泳道',
    'Column task limits apply to each swimlane individually' => '欄位任務限制個別應用於每個泳道',
    'Column task limits are applied to each swimlane individually' => '欄位任務限制個別應用於每個泳道',
    'Column task limits are applied across swimlanes' => '欄位任務限制應用於所有泳道',
    'Task limit: ' => '任務限制：',
    'Change to global tag' => '變更為全域標籤',
    'Do you really want to make the tag "%s" global?' => '您確定要將標籤 "%s" 設為全域嗎？',
    'Enable global tags for this project' => '啟用此專案的全域標籤',
    'Group membership(s):' => '群組成員：',
    '%s is a member of the following group(s): %s' => '%s 是以下群組的成員：%s',
    '%d/%d group(s) shown' => '顯示 %d/%d 個群組',
    'Subtask creation or modification' => '子任務建立或修改',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => '將任務移動到特定泳道時，將任務分配給特定使用者',
    'Comment' => '評論',
    'Collapse vertically' => '垂直收合',
    'Expand vertically' => '垂直展開',
    'MXN - Mexican Peso' => 'MXN - 墨西哥比索',
    'Estimated vs actual time per column' => '每個欄位的預估時間與實際時間',
    'HUF - Hungarian Forint' => 'HUF - 匈牙利福林',
    'XBT - Bitcoin' => 'XBT - 比特幣',
    'You must select a file to upload as your avatar!' => '您必須選擇要上傳的檔案作為您的頭像！',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '您上傳的檔案不是有效的圖片！ (僅允許 *.gif, *.jpg, *.jpeg 和 *.png)',
    'Automatically set the due date when the task is moved away from a specific column' => '當任務從特定欄位移開時，自動設定截止日期',
    'No other projects found.' => '找不到其他專案。',
    'Tasks copied successfully.' => '任務已成功複製。',
    'Unable to copy tasks.' => '無法複製任務。',
    'Theme' => '主題',
    'Theme:' => '主題：',
    'Light theme' => '淺色主題',
    'Dark theme' => '深色主題',
    'Automatic theme - Sync with system' => '自動主題 - 與系統同步',
    'Application managers or more' => '應用程式管理員或更高權限',
    'Administrators' => '管理員',
    'Visibility:' => '可見性：',
    'Standard users' => '標準使用者',
    'Visibility is required' => '可見性是必需的',
    'The visibility should be an app role' => '可見性應該是應用程式角色',
    'Reply' => '回覆',
    '%s wrote: ' => '%s 寫道：',
    'Number of visible tasks in this column and swimlane' => '此欄位和泳道中可見的任務數量',
    'Number of tasks in this swimlane' => '此泳道中的任務數量',
    'Unable to find another subtask in progress, you can close this window.' => '找不到其他正在進行的子任務，您可以關閉此視窗。',
    'This theme is invalid' => '此主題無效',
    'This role is invalid' => '此角色無效',
    'This timezone is invalid' => '此時區無效',
    'This language is invalid' => '此語言無效',
    'This URL is invalid' => '此 URL 無效',
    'Date format invalid' => '日期格式無效',
    'Time format invalid' => '時間格式無效',
    'Invalid Mail transport' => '無效的郵件傳輸',
    'Color invalid' => '顏色無效',
    'This value must be greater or equal to %d' => '此值必須大於或等於 %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '在檔案開頭加入 BOM（Microsoft Excel 需要）',
    'Just add these tag(s)' => '只需加入這些標籤',
    'Remove internal link(s)' => '移除內部連結',
    'Import tasks from another project' => '從其他專案匯入任務',
    'Select the project to copy tasks from' => '選擇要複製任務的專案',
    'The total maximum allowed attachments size is %sB.' => '允許的附件總大小上限為 %sB。',
    'Add attachments' => '加入附件',
    'Task #%d "%s" is overdue' => '任務 #%d "%s" 已逾期',
    'Enable notifications by default for all new users' => '預設啟用所有新使用者的通知',
    'Assign the task to its creator for specific columns if no assignee is set manually' => '若未手動指定負責人，則在指定欄位中將任務指派給建立者',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => '若未指派使用者，則在變更欄位移動到指定欄位時將任務指派給已登入使用者',
];
